VERSION 1.0 CLASS
BEGIN
  MultiUse = -1  'True
END
Attribute VB_Name = "CStockFont"
Attribute VB_GlobalNameSpace = False
Attribute VB_Creatable = True
Attribute VB_PredeclaredId = False
Attribute VB_Exposed = False
' *************************************************************
'  Copyright (C)1995-98, Karl E. Peterson
'  Author grants royalty-free rights to use this code within
'  compiled applications. Selling or otherwise distributing
'  this source code is not allowed without author's express
'  permission.
' *************************************************************
Option Explicit
'
' Win16/32 API calls required to use stock font objects
'
#If Win16 Then
   Private Declare Function GetStockObject Lib "GDI" (ByVal nIndex As Integer) As Integer
   Private Declare Function SendMessage Lib "User" (ByVal hWnd As Integer, ByVal wMsg As Integer, ByVal wParam As Integer, lParam As Any) As Long
   Private Declare Function DeleteObject Lib "GDI" (ByVal hObject As Integer) As Integer
#Else
   Private Declare Function GetStockObject Lib "gdi32" (ByVal nIndex As Long) As Long
   Private Declare Function SendMessage Lib "user32" Alias "SendMessageA" (ByVal hWnd As Long, ByVal wMsg As Long, ByVal wParam As Long, lParam As Any) As Long
   Private Declare Function DeleteObject Lib "gdi32" (ByVal hObject As Long) As Long
#End If
'
' SendMessage constants for font messages
'
Private Const WM_SETFONT = &H30
Private Const WM_GETFONT = &H31
'
' API stock font identifier constants
'
Private Const OEM_FIXED_FONT = 10
Private Const ANSI_FIXED_FONT = 11
Private Const ANSI_VAR_FONT = 12
Private Const SYSTEM_FONT = 13
Private Const DEVICE_DEFAULT_FONT = 14
Private Const SYSTEM_FIXED_FONT = 16
'
' Class property constants -- copy these into
' modules that use this class
'
Public Enum StockFonts
   sfOemFixed = 0
   sfAnsiVar = 1
   sfAnsiFixed = 2
   sfSystemVar = 3
   sfSystemFixed = 4
   sfDeviceDefault = 5
End Enum
'
' Variables to track class properties
'
Private m_Client As Object
#If Win16 Then
   Private m_hWnd As Integer
   Private m_sFont As Integer
#ElseIf Win32 Then
   Private m_hWnd As Long
   Private m_sFont As Long
#End If

' ************************************************
' Initialization and Termination
' ************************************************
Private Sub Class_Initialize()
   m_hWnd = 0
   m_sFont = SYSTEM_FIXED_FONT
End Sub

' ************************************************
' Properties
' ************************************************
Public Property Set Client(NewObj As Object)
   '
   ' Use error trapping to test hWnd
   ' Passed object *must* have an hWnd!
   '
   On Error Resume Next
      m_hWnd = NewObj.hWnd
      If Err Then m_hWnd = 0
   On Error GoTo 0
   '
   ' Set Client property
   '
   If m_hWnd Then
      Set m_Client = NewObj
   Else
      Err.Raise Number:=vbObjectError + 1, _
                Source:="CStockFont", _
                Description:="Client object must support the hWnd property."
   End If
End Property

Public Property Get Client() As Object
   '
   ' Return client object
   '
   Set Client = m_Client
End Property

Public Property Let StockFont(ByVal NewVal As StockFonts)
   #If Win16 Then
      Dim hFont As Integer
   #ElseIf Win32 Then
      Dim hFont As Long
   #End If
   '
   ' Store API constant in StockFont property
   ' Requires conversion from class constant
   '
   Select Case NewVal
      Case sfOemFixed
         m_sFont = OEM_FIXED_FONT
      Case sfAnsiVar
         m_sFont = ANSI_VAR_FONT
      Case sfAnsiFixed
         m_sFont = ANSI_FIXED_FONT
      Case sfSystemVar
         m_sFont = SYSTEM_FONT
      Case sfSystemFixed
         m_sFont = SYSTEM_FIXED_FONT
      Case sfDeviceDefault
         m_sFont = DEVICE_DEFAULT_FONT
   End Select
   '
   ' Select the stock font into the client textbox
   ' Always use DeleteObject to clean up
   '
   hFont = GetStockObject(m_sFont)
   Call SendMessage(m_hWnd, WM_SETFONT, hFont, False)
   Call DeleteObject(hFont)
End Property

Public Property Get StockFont() As StockFonts
   '
   ' Return StockFont property
   ' Requires conversion from the stored API constant
   '
   Select Case m_sFont
      Case OEM_FIXED_FONT
         StockFont = sfOemFixed
      Case ANSI_FIXED_FONT
         StockFont = sfAnsiFixed
      Case ANSI_VAR_FONT
         StockFont = sfAnsiVar
      Case SYSTEM_FONT
         StockFont = sfSystemVar
      Case DEVICE_DEFAULT_FONT
         StockFont = sfDeviceDefault
      Case SYSTEM_FIXED_FONT
         StockFont = sfSystemFixed
   End Select
End Property

